PercolatorClient

Struct PercolatorClient 

pub struct PercolatorClient {
    pub client: RpcClient,
    pub program_id: Pubkey,
    pub engine_state: Pubkey,
}
A high-level client for interacting with the Percolator risk engine via RPC.

PercolatorClient simplifies the process of sending transactions and fetching protocol state by encapsulating the RPC client and instruction building.

Fields

client: RpcClient

The underlying Solana RPC client.

program_id: Pubkey

The public key of the Percolator program (or its wrapper).

engine_state: Pubkey

The public key of the RiskEngine state account.

Implementations

Source

impl PercolatorClient

pub fn new(rpc_url: &str, program_id: Pubkey, engine_state: Pubkey) -> Self

Creates a new PercolatorClient.

pub fn get_engine_state(&self) -> Result<RiskEngine, Box<dyn Error>>

Fetches the current RiskEngine state from the blockchain.

pub fn get_account( &self, index: usize, ) -> Result<Option<Account>, Box<dyn Error>>

Fetches a specific Account from the engine by its index.

pub fn send_deposit( &self, payer: &Keypair, account_index: u64, amount: u128, now_slot: u64, ) -> Result<String, Box<dyn Error>>

Sends a Deposit transaction.

pub fn send_withdraw( &self, payer: &Keypair, account_index: u64, amount: u128, now_slot: u64, oracle_price: u64, ) -> Result<String, Box<dyn Error>>

Sends a Withdraw transaction.

pub fn send_trade( &self, payer: &Keypair, lp_index: u64, user_index: u64, now_slot: u64, oracle_price: u64, size: i128, ) -> Result<String, Box<dyn Error>>

Sends an ExecuteTrade transaction.

pub fn send_crank( &self, payer: &Keypair, caller_index: u64, now_slot: u64, oracle_price: u64, funding_rate: i64, allow_panic: bool, ) -> Result<String, Box<dyn Error>>

Sends a KeeperCrank transaction.